LinkProvider class

dsalink Provider for the Browser

Constructors

LinkProvider(String brokerUrl, String prefix, {Map? defaultNodes, Map<String, NodeFactory>? profiles, NodeProvider? provider, DataStorage? dataStore, bool loadNodes = false, bool isRequester = true, bool isResponder = true, String? token})

Properties

brokerUrl String
getter/setter pair
dataStore DataStorage?
getter/setter pair
defaultNodes Map?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isRequester bool
getter/setter pair
isResponder bool
getter/setter pair
getter/setter pair
loadNodes bool
getter/setter pair
onRequesterReady Future<Requester>?
no setter
prefix String
getter/setter pair
privateKey PrivateKey
getter/setter pair
profiles Map<String, NodeFactory>?
getter/setter pair
provider NodeProvider?
getter/setter pair
requester Requester?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String?
getter/setter pair

Methods

addNode(String path, Map m) LocalNode?
close() → void
connect() Future
getNode(String path) LocalNode?
init() Future
initLinkWithPrivateKey() Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onValueChange(String path, {int cacheLevel = 1}) Stream<ValueUpdate>
removeNode(String path) → void
resetSavedNodes() Future
save() Future
syncValue(String path) → void
Remote Path of Responder
toString() String
A string representation of this object.
inherited
updateValue(String path, dynamic value) → void
val(String path, [dynamic value = unspecified]) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String path) LocalNode?
operator ~() LocalNode?