browser_client library

Base API for DSA in the Browser

Classes

a client link for websocket
a client link for both http and ws
DataStorage
A Storage System for DSA Data
LocalDataStorage
Storage for DSA in Local Storage
SynchronousDataStorage
A Synchronous Storage System for DSA Data
WebSocketConnection

Functions

getPrivateKey({DataStorage? storage}) Future<PrivateKey?>
Get a Private Key using the specified storage strategy. If storage is not specified, it uses the LocalDataStorage class.