DataStorage class abstract

A Storage System for DSA Data

Implementers

Constructors

DataStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String key) Future<String>
Get a key's value.
has(String key) Future<bool>
Check if a key is stored.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) Future<String>
Remove the specified key.
store(String key, String value) Future
Store a key value pair.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited