LocalDataStorage class

Storage for DSA in Local Storage

Inheritance
Implemented types

Constructors

LocalDataStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String key) Future<String>
Get a key's value.
override
getSync(String key) String
Get a key's value.
override
has(String key) Future<bool>
Check if a key is stored.
override
hasSync(String key) bool
Check if a key is stored.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) Future<String>
Remove the specified key.
override
removeSync(String key) String
Remove the specified key.
override
store(String key, String value) Future
Store a key value pair.
override
storeSync(String key, String value) → void
Store a key value pair.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

INSTANCE LocalDataStorage
final