SynchronousDataStorage class abstract
A Synchronous Storage System for DSA Data
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getSync(
String key) → String - Get a key's value.
-
hasSync(
String key) → bool - Check if a key is stored.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeSync(
String key) → String - Remove the specified key.
-
storeSync(
String key, String value) → void - Store a key value pair.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited