WebSocketConnection class

Inheritance

Constructors

WebSocketConnection(WebSocket socket, ClientLink clientLink, {Function? onConnect, bool enableAck = false, DsCodec? useCodec})
clientLink is not needed when websocket works in server link

Properties

final
codec DsCodec
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
nextMsgId int
getter/setter pair
onConnect Function?
getter/setter pair
onDisconnected Future<bool>
return true if it's authentication error
no setteroverride
onRequesterReady Future<ConnectionChannel>
trigger when requester channel is Ready
no setteroverride
opened bool
no setter
pendingAcks ListQueue<ConnectionAckGroup>
getter/setter pairinherited
pingTimer Timer?
getter/setter pair
requesterChannel ConnectionChannel
no setteroverride
responderChannel ConnectionChannel
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socket → WebSocket
final

Methods

ack(int ackId) → void
inherited
addConnCommand(String? key, Object? value) → void
add server command, will be called only when used as server connection
override
checkBrowserThrottling() → void
close() → void
close the connection
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onPingTimer(Timer? t) → void
requireSend() → void
notify the connection channel need to send data
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited