addNode method

LocalNode? addNode(
  1. String path,
  2. Map m
)

Adds a node with the given configuration in m at the given path. In order for this method to work, the node provider must be mutable. If you did not specify a custom node provider, the created provider is mutable.

Implementation

LocalNode? addNode(String path, Map m) {
  if (provider is! MutableNodeProvider) {
    throw Exception('Unable to Modify Node Provider: It is not mutable.');
  }
  return (provider as MutableNodeProvider).addNode(path, m);
}