syncValue method
Gets the value for path and forcibly updates the value to the same exact value.
Implementation
void syncValue(String path) {
var n = this[path];
n?.updateValue(n.lastValueUpdate!.value!, force: true);
}
Gets the value for path and forcibly updates the value to the same exact value.
void syncValue(String path) {
var n = this[path];
n?.updateValue(n.lastValueUpdate!.value!, force: true);
}