updateValue method

void updateValue(
  1. String path,
  2. dynamic value
)

Updates the value of the node at the given path to value. In order for this method to work, the node provider must be mutable. If you did not specify a custom node provider, the created provider is mutable.

Implementation

void updateValue(String path, dynamic value) {
  if (provider is! MutableNodeProvider) {
    throw Exception('Unable to Modify Node Provider: It is not mutable.');
  }
  (provider as MutableNodeProvider).updateValue(path, value);
}