common library

Shared APIs between all DSA Components.

Classes

Base Class for Links
Base Class for Client Link implementations.
Connection
ConnectionAckGroup
ConnectionChannel
ConnectionHandler
ConnectionProcessor
DSError
ErrorPhase
Node
Base Class for any and all nodes in the SDK. If you are writing a link, please look at the dsalink.responder.SimpleNode class.
PassiveChannel
Path
Utility class for node and config/attribute paths.
Permission
PermissionList
ProcessorResult
generate message right before sending to get the latest update return messages and the processors that need ack callback
Base Class for Server Link implementations.
ServerLinkManager
StreamStatus
DSA Stream Status
Table
TableColumn
TableColumns
TableMetadata
Unspecified
Unspecified means that something has never been set.
ValueUpdate
Represents an update to a value subscription.

Constants

unspecified → const Unspecified
Marks something as being unspecified.

Properties

defaultProfileMap Map
getter/setter pair

Typedefs

ValueCallback<T> = T Function(Object? value)
ValueUpdateCallback<T> = T Function(ValueUpdate update)