BaseLink class abstract

Base Class for Links

Implementers

Constructors

BaseLink()

Properties

hashCode int
The hash code for this object.
no setterinherited
nonce ECDH?
no setter
onRequesterReady Future<Requester?>
trigger when requester channel is Ready
no setter
requester Requester?
no setter
responder Responder?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited