Connection class abstract

Implementers

Constructors

Connection()

Properties

codec DsCodec
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
onDisconnected Future<bool>
return true if it's authentication error
no setter
onRequesterReady Future<ConnectionChannel>
trigger when requester channel is Ready
no setter
pendingAcks ListQueue<ConnectionAckGroup>
getter/setter pair
requesterChannel ConnectionChannel
no setter
responderChannel ConnectionChannel
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

ack(int ackId) → void
addConnCommand(String key, Object value) → void
send a connection command
close() → void
close the connection
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requireSend() → void
notify the connection channel need to send data
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited