ConnectionAckGroup class
Constructors
-
ConnectionAckGroup(int ackId, int startTime, List<
ConnectionProcessor> processors)
Properties
- ackId ↔ int
-
getter/setter pair
- expectedAckTime ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
processors
↔ List<
ConnectionProcessor> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime ↔ int
-
getter/setter pair
Methods
-
ackAll(
int ackid, int time) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited