ConnectionChannel class abstract

Implementers

Constructors

ConnectionChannel()

Properties

connected bool
no setter
hashCode int
The hash code for this object.
no setterinherited
isReady bool
whether the connection is ready to send and receive data
no setter
onConnected Future<ConnectionChannel>
no setter
onDisconnected Future<ConnectionChannel>
no setter
onReceive Stream<List>
receive data from method stream
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendWhenReady(ConnectionHandler handler) → void
raw connection need to handle error and resending of data, so it can only send one map at a time a new getData function will always overwrite the previous one; requester and responder should handle the merging of methods
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited