sendWhenReady abstract method

void sendWhenReady(
  1. ConnectionHandler handler
)

raw connection need to handle error and resending of data, so it can only send one map at a time a new getData function will always overwrite the previous one; requester and responder should handle the merging of methods

Implementation

void sendWhenReady(ConnectionHandler handler);