ConnectionHandler class abstract
Constructors
Properties
- connection ↔ ConnectionChannel?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addProcessor(
ConnectionProcessor processor) → void - a processor function that's called just before the data is sent same processor won't be added to the list twice inside processor, send() data that only need to appear once per data frame
-
addToSendList(
Map m) → void -
clearProcessors(
) → void -
getSendingData(
int currentTime, int waitingAckId) → ProcessorResult - gather all the changes from
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onData(
List m) → void -
onDisconnected(
) → void -
onReconnected(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited