addProcessor method
a processor function that's called just before the data is sent same processor won't be added to the list twice inside processor, send() data that only need to appear once per data frame
Implementation
void addProcessor(ConnectionProcessor processor) {
_processors.add(processor);
if (!_pendingSend) {
if (_conn != null) {
_conn?.sendWhenReady(this);
}
_pendingSend = true;
}
}