ConnectionProcessor class abstract

Implementers

Constructors

ConnectionProcessor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

ackReceived(int receiveAckId, int startTime, int currentTime) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startSendingData(int waitingAckId, int currentTime) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaultCacheSize int
getter/setter pair

Constants

ACK_WAIT_COUNT → const int