PassiveChannel class
- Implemented types
Constructors
- PassiveChannel(Connection? conn, [bool connected = false])
Properties
- conn → Connection?
-
final
- connected ↔ bool
-
getter/setter pairoverride-getter
- handler ↔ ConnectionHandler?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isReady ↔ bool
-
whether the connection is ready to send and receive data
getter/setter pairoverride-getter
-
onConnectController
→ Completer<
ConnectionChannel> -
final
-
onConnected
→ Future<
ConnectionChannel> -
no setteroverride
-
onDisconnectController
→ Completer<
ConnectionChannel> -
final
-
onDisconnected
→ Future<
ConnectionChannel> -
no setteroverride
-
onReceive
→ Stream<
List> -
receive data from method stream
no setteroverride
-
onReceiveController
→ StreamController<
List> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getSendingData(
int currentTime, int waitingAckId) → ProcessorResult? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendWhenReady(
ConnectionHandler handler) → void -
raw connection need to handle error and resending of data, so it can only send one map at a time
a new getData function will always overwrite the previous one;
requester and responder should handle the merging of methods
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateConnect(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited