Permission class

Constructors

Permission()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(Object? obj, [int defaultVal = NEVER]) int

Constants

CONFIG → const int
config the node
LIST → const int
list node
nameParser → const Map<String, int>
names → const List<String>
NEVER → const int
something that can never happen
NONE → const int
now allowed to do anything
READ → const int
read node
WRITE → const int
write attribute and value