PermissionList class
Constructors
Properties
- defaultPermission ↔ int
-
getter/setter pair
-
groupMatchs
↔ Map<
String, int> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
idMatchs
↔ Map<
String, int> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPermission(
Responder responder) → int? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updatePermissions(
List data) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited