ServerLink class abstract

Base Class for Server Link implementations.

Inheritance

Constructors

ServerLink()

Properties

dsId String
dsId or username
no setter
hashCode int
The hash code for this object.
no setterinherited
nonce ECDH?
no setterinherited
onRequesterReady Future<Requester?>
trigger when requester channel is Ready
no setterinherited
publicKey PublicKey?
no setter
requester Requester?
no setterinherited
responder Responder?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session String?
no setter

Methods

close() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited