ServerLinkManager class abstract

Constructors

ServerLinkManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

return true if link is added
getLinkAndConnectNode(String dsId, {String sessionId = ''}) ServerLink?
getLinkPath(String dsId, String? token) String?
getRequester(String dsId) Requester?
getResponder(String dsId, NodeProvider nodeProvider, [String? sessionId = '', bool trusted = false]) Responder?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onLinkDisconnected(ServerLink link) → void
toString() String
A string representation of this object.
inherited
updateLinkData(String dsId, Map? m) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited