Table class

Constructors

Table(List<TableColumn> columns, List<List> rows, {Map? meta})

Properties

columns List<TableColumn>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
meta Map?
getter/setter pair
rows List<List>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited