TableColumn class

Constructors

TableColumn(String? name, String? type, [Object? defaultValue])

Properties

defaultValue Object?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
getter/setter pair

Methods

getData() Map
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parseColumns(List list) List<TableColumn>?
parse List of Map into TableColumn
serializeColumns(List list) List<Map>
convert tableColumns into List of Map