ValueUpdate class

Represents an update to a value subscription.

Constructors

ValueUpdate(Object? value, {String? ts, Map? meta, String? status, int count = 1, num sum = double.nan, num min = double.nan, num max = double.nan})
ValueUpdate.merge(ValueUpdate oldUpdate, ValueUpdate newUpdate)

Properties

count int
How many updates have happened since the last response.
getter/setter pair
created DateTime?
The timestamp for when this value update was created.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
latency Duration
Calculates the latency
no setter
max num
The maximum value if one or more numeric values has been skipped.
getter/setter pair
min num
The minimum value if one or more numeric values has been skipped.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
The current status of this value.
getter/setter pair
storedData Object?
could be the value or the key stored by ValueStorage
getter/setter pair
sum num
The sum value if one or more numeric values has been skipped.
getter/setter pair
timestamp DateTime
Gets a DateTime representation of the timestamp for this value.
no setter
ts String?
A String representation of the timestamp for this value.
getter/setter pair
value Object?
The value for this update.
getter/setter pair
waitingAck int
The id of the ack we are waiting for.
getter/setter pair

Methods

cloneForAckQueue() ValueUpdate
equals(ValueUpdate other) bool
mergeAdd(ValueUpdate newUpdate) → void
merge the new update into existing instance
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map
Generates a map representation of this value update.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

TIME_ZONE String
DSA formatted timezone.
final

Static Methods

getTs() String
Generates a timestamp in the proper DSA format.