onRemoving method
Callback used to notify a node that it is about to be removed.
Implementation
@override
void onRemoving() {
if (database != null) {
database?.close();
}
}
Callback used to notify a node that it is about to be removed.
@override
void onRemoving() {
if (database != null) {
database?.close();
}
}