ValueEntry class

Constructors

ValueEntry(String group, String path, String timestamp, dynamic value)

Properties

group String
final
hashCode int
The hash code for this object.
no setterinherited
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time DateTime
no setter
timestamp String
final
value → dynamic
final

Methods

asPair() ValuePair
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited