nodes library
Helper Nodes for Responders
Classes
- CallbackNode
- A Simple Node which delegates all basic methods to given functions.
- DeleteActionNode
- An Action for Deleting a Given Node
- DsaJsonNode
- LazyValueNode
- A Lazy Value Node
- NodeNamer
- ResolvingNodeProvider
- SimpleActionNode
- A Simple Action Node
- SingleNodeProvider
- A Node Provider for a Single Node
- UpgradableNode
Typedefs
- ActionFunction = dynamic Function(Map params)
- A function that is called when an action is invoked.
- ChildChangedCallback = void Function(String name, Node node)
- Represents a function that is called when a child node has changed.
- LoadChildCallback = SimpleNode Function(String name, Map data, SimpleNodeProvider provider)
- Represents a function that is called on a node when a child is loading.
- NodeUpgradeFunction = void Function(int from)
- ResolveNodeHandler = Future Function(CallbackNode node)
- SimpleCallback = void Function()
- Represents a Simple Callback Function