onCreated method
Callback used to notify a node that it was created. This is called after a node is deserialized as well.
Implementation
@override
void onCreated() {
if (onCreatedCallback != null) {
onCreatedCallback!();
}
}
Callback used to notify a node that it was created. This is called after a node is deserialized as well.
@override
void onCreated() {
if (onCreatedCallback != null) {
onCreatedCallback!();
}
}