onRemoving method
Callback used to notify a node that it is about to be removed.
Implementation
@override
void onRemoving() {
if (onRemovingCallback != null) {
onRemovingCallback!();
}
}
Callback used to notify a node that it is about to be removed.
@override
void onRemoving() {
if (onRemovingCallback != null) {
onRemovingCallback!();
}
}