SimpleActionNode constructor

SimpleActionNode(
  1. String path,
  2. ActionFunction function, [
  3. SimpleNodeProvider? provider
])

When this action is invoked, the given function will be called with the parameters and then the result of the function will be returned.

Implementation

SimpleActionNode(String path, this.function, [SimpleNodeProvider? provider])
  : super(path, provider);