SingleNodeProvider class

A Node Provider for a Single Node

Inheritance

Constructors

SingleNodeProvider(LocalNode node)

Properties

hashCode int
The hash code for this object.
no setterinherited
node LocalNode
final
permissions IPermissionManager
Get Permissions.
getter/setter pairoverride-getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createResponder(String? dsId, String sessionId) Responder
Create a Responder
override
getNode(String? path) LocalNode
Gets an existing node.
override
getOrCreateNode(String path, [bool addToTree = true]) LocalNode
Gets a node at the given path if it exists. If it does not exist, create a new node and return it.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String path) LocalNode?
Gets an existing node, or creates a dummy node for a requester to listen on.
inherited
operator ~() LocalNode
Get the root node.
inherited