BrokerQueryManager class
Constructors
- BrokerQueryManager(NodeProvider provider)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- provider ↔ NodeProvider
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseDql(
String str) → BrokerQueryCommand? -
parseList(
List str) → BrokerQueryCommand? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited