InvokeController class

Implemented types

Constructors

InvokeController(RemoteNode node, Requester requester, Map params, [int maxPermission = Permission.CONFIG, RequestConsumer? fetchRawReq])

Properties

hashCode int
The hash code for this object.
no setterinherited
lastStatus String
getter/setter pair
mode String
getter/setter pair
node RemoteNode
final
requester Requester
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDisconnect() → void
override
onReconnect() → void
override
onUpdate(String streamStatus, List? updates, List? columns, Map? meta, DSError? error) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getNodeColumns(RemoteNode node) List<TableColumn>?