ListDefListener class

Constructors

ListDefListener(RemoteNode node, Requester requester, void callback(RequesterListUpdate u))

Properties

hashCode int
The hash code for this object.
no setterinherited
listener StreamSubscription
getter/setter pair
node RemoteNode
final
ready bool
getter/setter pair
requester Requester
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited