RemoteNodeCache class

manage cached nodes for requester TODO: cleanup nodes that are no longer in use

Constructors

RemoteNodeCache()

Properties

cachedNodePaths Iterable<String>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
clearCachedNode(String path) → void
getDefNode(String path, String defName) Node?
getRemoteNode(String path) RemoteNode
isNodeCached(String path) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRemoteChildNode(RemoteNode parent, String name, Map m) RemoteNode?
update node with a map.

Operators

operator ==(Object other) bool
The equality operator.
inherited