RemoveController class

A controller for removing a request.

This class implements the RequestUpdater interface and is responsible for handling the removal of a request. It provides methods for updating the status of the request and handling disconnection and reconnection events.

Implemented types

Constructors

RemoveController(Requester requester, String path)
Creates a new RemoveController instance.

Properties

completer Completer<RequesterUpdate>
final
future Future<RequesterUpdate>
no setter
hashCode int
The hash code for this object.
no setterinherited
path String
final
requester Requester
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDisconnect() → void
Called when the requester is disconnected.
override
onReconnect() → void
Called when the requester is reconnected.
override
onUpdate(String? status, List? updates, List? columns, Map? meta, DSError? error) → void
Called when the request is updated.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited