RemoveController constructor

RemoveController(
  1. Requester requester,
  2. String path
)

Creates a new RemoveController instance.

The requester parameter is the requester object used to send the remove request. The path parameter is the path of the request to be removed.

Implementation

RemoveController(this.requester, this.path) {
  var reqMap = <String, dynamic>{'method': 'remove', 'path': path};

  //_request =
  requester._sendRequest(reqMap, this);
}