onUpdate method
void
onUpdate()
override
Called when the request is updated.
The status parameter represents the status of the request.
The updates parameter contains the list of updates.
The columns parameter contains the list of columns.
The meta parameter contains the metadata.
The error parameter represents any error that occurred during the update.
Implementation
@override
void onUpdate(
String? status,
List? updates,
List? columns,
Map? meta,
DSError? error,
) {
// TODO implement error
completer.complete(RequesterUpdate(status));
}