ReqSubscribeController class

Constructors

ReqSubscribeController(RemoteNode node, Requester requester)

Properties

callbacks Map<Function, int>
getter/setter pair
currentQos int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
node RemoteNode
final
requester Requester
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sid int
getter/setter pair

Methods

addValue(ValueUpdate update) → void
listen(dynamic callback(ValueUpdate update), int qos) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
unlisten(dynamic callback(ValueUpdate update)) → void
updateQos() bool

Operators

operator ==(Object other) bool
The equality operator.
inherited