RequestUpdater class abstract

Implementers

Constructors

RequestUpdater()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDisconnect() → void
onReconnect() → void
onUpdate(String status, List? updates, List? columns, Map? meta, DSError? error) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited