changes property
this is only a list of changed fields when changes is null, means everything could have been changed
Implementation
List? changes;
this is only a list of changed fields when changes is null, means everything could have been changed
List? changes;