resend method
Resends the data if the previous sending failed.
This method adds the data to the send list of the requester to be resent later.
Implementation
@override
void resend() {
prepareSending();
}
Resends the data if the previous sending failed.
This method adds the data to the send list of the requester to be resent later.
@override
void resend() {
prepareSending();
}