ConfigSetting class

Constructors

ConfigSetting(String name, String type, {Object? defaultValue})
whether broker need to maintain the change of config value when ds link is offline
ConfigSetting.fromMap(String name, Map m)

Properties

defaultValue Object?
need permission to read
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeConfig(LocalNodeImpl node, Responder responder) DSError?
setConfig(Object value, LocalNodeImpl node, Responder responder) DSError?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited