Configs class

Constructors

Configs()

Properties

configs Map<String, ConfigSetting>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

load(Map inputs) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaultConfig ConfigSetting
final
global Configs
final

Static Methods

getConfig(String name, Node? profile) Object?