getOrCreateSubscriptionStorage abstract method

ISubscriptionResponderStorage getOrCreateSubscriptionStorage(
  1. String responderPath
)

get subscription storage responder path point to a local responder node which means the dsalink on the other side of the connection is a requester

Implementation

ISubscriptionResponderStorage getOrCreateSubscriptionStorage(
  String responderPath,
);