getLoadedValues abstract method

List<ValueUpdate> getLoadedValues()

return the existing storage values should be called only during application initialization and value will only be available after parent's load() function is finished

Implementation

List<ValueUpdate> getLoadedValues();