removeValue abstract method

void removeValue(
  1. ValueUpdate value
)

for some database it's easier to remove data one by one removeValue and valueRemoved will be both called, either one can be used

Implementation

void removeValue(ValueUpdate value);