setValue abstract method

void setValue(
  1. Iterable<ValueUpdate> removes,
  2. ValueUpdate newValue
)

set value to newValue and clear all existing values in the storage removes is only designed for database that can't directly remove all data in a key. ValueUpdate.storedData can be used to store any helper data for the storage class

Implementation

void setValue(Iterable<ValueUpdate> removes, ValueUpdate newValue);