valueRemoved method
for some database it's easier to remove multiple data together
removeValue and valueRemoved will be both called, either one can be used
updates are all the remaining value that are still in the list
Implementation
void valueRemoved(Iterable<ValueUpdate> updates) {}