ISubscriptionResponderStorage class abstract
a storage container for one dsalink different dsalink will have different ISubscriptionResponderStorage
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- responderPath → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
destroy(
) → void -
destroyValue(
String valuePath) → void -
getOrCreateValue(
String valuePath) → ISubscriptionNodeStorage -
load(
) → Future< List< ISubscriptionNodeStorage> > - load all saved subscriptions should be called only during application initialization
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited