LiveTable class

A Live-Updating Table

Constructors

LiveTable([List<TableColumn>? columns])
factory
LiveTable.create(List<TableColumn>? columns, List<LiveTableRow>? rows)

Properties

autoStartSend bool
getter/setter pair
columns List<TableColumn>?
final
hashCode int
The hash code for this object.
no setterinherited
response InvokeResponse?
no setter
rows List<LiveTableRow>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
close([bool isFromRequester = false]) → void
createRow(List? values, {bool ready = true}) LiveTableRow
doOnClose(Function f) → void
getCurrentState([int from = -1]) List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRowUpdate(LiveTableRow row) → void
override() → void
refresh([int idx = -1]) → void
reindex() → void
resend() → void
sendTo(InvokeResponse resp) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited