LiveTableRow class

Constructors

LiveTableRow(LiveTable table, List values)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table LiveTable
final
values List
final

Methods

delete() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValue(int idx, dynamic value) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited