exists property
bool
get
exists
Checks if this node exists. list and subscribe can be called on a node that doesn't exist Other things like set remove, and invoke can only be applied to an existing node.
Implementation
bool get exists => true;