listReady property
bool
get
listReady
whether the node is ready for returning a list response
Implementation
bool get listReady => true;
whether the node is ready for returning a list response
bool get listReady => true;