LocalNodeImpl class abstract

Inheritance
Implementers

Constructors

LocalNodeImpl(String path)

Properties

attributes Map<String, Object?>
Node Attributes
getter/setter pairinherited
callbacks Map<ValueUpdateCallback, int>
Subscription Callbacks
getter/setter pairinherited
children Map<String, Node>
Node Children Map of Child Name to Child Node
getter/setter pairinherited
configs Map
Node Configs
getter/setter pairinherited
disconnected String?
Disconnected Timestamp
no setterinherited
exists bool
Checks if this node exists. list and subscribe can be called on a node that doesn't exist Other things like set remove, and invoke can only be applied to an existing node.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasSubscriber bool
Checks if this node has a subscriber. Use this for things like polling when you only want to do something if the node is subscribed to.
no setterinherited
lastValueUpdate ValueUpdate?
Gets the last value update of this node.
no setterinherited
listChangeController BroadcastStreamController<String>
Changes to nodes will be added to this controller's stream. See updateList.
no setterinherited
listReady bool
whether the node is ready for returning a list response
no setterinherited
listStream Stream<String>
List Stream. See listChangeController.
no setterinherited
loaded bool
no setter
path String
Node Path
finalinherited
profile Node?
This node's profile.
getter/setter pairinherited
provider NodeProvider?
Node Provider
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
Gets the current value of this node.
no setterinherited
valueReady bool
Is the value ready?
no setterinherited

Methods

addChild(String name, Node node) → void
Adds a child to this node.
inherited
clearValue() → void
inherited
forEachAttribute(void callback(String name, Object? value)) → void
inherited
forEachChild(void callback(String name, Node? node)) → void
Iterates over all the children of this node and passes them to the specified callback.
inherited
forEachConfig(void callback(dynamic name, dynamic value)) → void
inherited
get(String name) Object?
Get a property of this node. If name starts with '$', this will fetch a config. If name starts with a '@', this will fetch an attribute. Otherwise this will fetch a child.
inherited
getAttribute(String name) Object?
Get an Attribute
inherited
getChild(String name) Node?
Get a Child Node
inherited
getConfig(String name) Object?
Get a Config
inherited
getDisconnectedListResponse() List
inherited
getInvokePermission() int
Gets the invoke permission for this node.
inherited
getOverideAttributes(String attr) Object?
same as attributes for local node but different on remote node
inherited
getSetPermission() int
Gets the set permission for this node.
inherited
getSimpleMap() Map
Gets a map for the data that will be listed in the parent node's children property.
inherited
invoke(Map params, Responder responder, InvokeResponse response, Node parentNode, [int maxPermission = Permission.CONFIG]) InvokeResponse
Called by the link internals to invoke this node.
inherited
load(Map m) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAllListCancel() → void
Callback for when all lists are canceled.
inherited
onStartListListen() → void
Callback for when listing this node has started.
inherited
overrideListChangeController(BroadcastStreamController<String> controller) → void
inherited
removeAttribute(String name, Responder responder, Response? response) Response?
Called by the link internals to remove an attribute from this node.
override
removeChild(dynamic input) String?
Remove a child from this node. input can be either an instance of Node or a String.
inherited
removeConfig(String name, Responder responder, Response? response) Response?
Called by the link internals to remove a config from this node.
override
serialize(bool withChildren) Map
setAttribute(String name, Object value, Responder responder, Response? response) Response?
Called by the link internals to set an attribute on this node.
override
setConfig(String name, Object value, Responder responder, Response? response) Response?
Called by the link internals to set a config on this node.
override
setValue(Object? value, Responder? responder, Response? response, [int maxPermission = Permission.CONFIG]) Response?
Called by the link internals to set a value of a node.
override
subscribe(dynamic callback(ValueUpdate update), [int qos = 0]) RespSubscribeListener
Subscribes the given callback to this node.
inherited
toString() String
A string representation of this object.
inherited
unsubscribe(ValueUpdateCallback callback) → void
Unsubscribe the given callback from this node.
inherited
updateList(String name) → void
updateValue(Object? update, {bool force = false}) → void
Updates this node's value to the specified value.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String name) Object?
Shortcut to get.
inherited
operator []=(String name, Object value) → void
Set a config, attribute, or child on this node.
inherited