MutableNodeProvider class abstract

Interface for node providers that are mutable.

Implementers

Constructors

MutableNodeProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addNode(String path, Map m) LocalNode?
Adds a node at the given path that is initialized with the given data in m.
addProfile(String name, NodeFactory factory) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeNode(String path) → void
Removes the node specified at path.
toString() String
A string representation of this object.
inherited
updateValue(String path, Object value) → void
Updates the value of the node at path to the given value.

Operators

operator ==(Object other) bool
The equality operator.
inherited