RespSubscribeController class

Constructors

RespSubscribeController(SubscribeResponse response, LocalNode node, int sid, bool _permitted, int qos)

Properties

caching bool
no getter
cachingQueue bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastValue ValueUpdate?
getter/setter pair
lastValues List<ValueUpdate>
getter/setter pair
node LocalNode
final
permitted bool
no getter
persist bool
no getter
qosLevel int
no getter
response SubscribeResponse
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sid int
getter/setter pair
waitingValues ListQueue<ValueUpdate>?
getter/setter pair

Methods

addValue(ValueUpdate? val) → void
destroy() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAck(int ackId) → void
process(int waitingAckId) List
resetCache(List<ValueUpdate> values) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited