SerializableNodeProvider class abstract

Interface for node providers that are serializable.

Implementers

Constructors

SerializableNodeProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init([Map m, Map<String, NodeFactory> profiles]) → void
Initialize the node provider.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
persist([bool now = false]) → void
Persist the node provider.
save() Map
Save the node provider to a map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited