isStubNode property
bool
get
isStubNode
Is this node a stub node? Stub nodes are nodes which are stored in the tree, but are not actually part of their parent.
Implementation
bool get isStubNode => _stub;