onCreated method
void
onCreated()
Callback used to notify a node that it was created. This is called after a node is deserialized as well.
Implementation
void onCreated() {}
Callback used to notify a node that it was created. This is called after a node is deserialized as well.
void onCreated() {}