onInvoke method

dynamic onInvoke(
  1. Map params
)

This is called when this node is invoked. You can return the following types from this method:

You can also return a future that resolves to one (like if the method is async) of the following types:

Implementation

dynamic onInvoke(Map params) {
  return null;
}