onLoadChild method

SimpleNode? onLoadChild(
  1. String name,
  2. Map data,
  3. SimpleNodeProvider provider
)

Callback to override how a child of this node is loaded. If this method returns null, the default strategy is used.

Implementation

SimpleNode? onLoadChild(String name, Map data, SimpleNodeProvider provider) {
  return null;
}