onSetAttribute method

bool onSetAttribute(
  1. String name,
  2. dynamic value
)

Callback used to accept or reject a value of an attribute when it is set. Return true to reject the value, and false to accept it.

Implementation

bool onSetAttribute(String name, dynamic value) => false;