onSetValue method

bool onSetValue(
  1. dynamic val
)

Callback used to accept or reject a value when it is set. Return true to reject the value, and false to accept it.

Implementation

bool onSetValue(dynamic val) => false;