removeChild method

  1. @override
String? removeChild(
  1. dynamic input
)
override

Removes a child from this node. If input is a String, a child named with the specified input is removed. If input is a Node, the child that owns that node is removed. The name of the removed node is returned.

Implementation

@override
String? removeChild(dynamic input) {
  var name = super.removeChild(input);
  if (name != null) {
    updateList(name);
  }
  return name;
}