serializable property
Marks this node as being serializable. If true, this node can be serialized into a JSON file and then loaded back. If false, this node can't be serialized into a JSON file.
Implementation
bool serializable = true;
Marks this node as being serializable. If true, this node can be serialized into a JSON file and then loaded back. If false, this node can't be serialized into a JSON file.
bool serializable = true;