type property

String get type

Gets the current value type of this node. This is the $type config. If it does not exist, then null is returned.

Implementation

String get type => configs[r'$type'] as String;
set type (String? value)

Sets the value type of this node. This is the $type config. If this is set to null, then the value type is removed.

Implementation

set type(String? value) {
  if (value == null) {
    configs.remove(r'$type');
  } else {
    configs[r'$type'] = value;
  }

  updateList(r'$type');
}