instance property
Global instance. This is by default always the first instance of SimpleNodeProvider.
Implementation
static SimpleNodeProvider? instance;
Global instance. This is by default always the first instance of SimpleNodeProvider.
static SimpleNodeProvider? instance;