toString method

  1. @override
String toString({
  1. bool showInstances = false,
})
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString({bool showInstances = false}) {
  var buff = StringBuffer();

  void doNode(LocalNode node, [int depth = 0]) {
    var p = Path(node.path);
    buff.write("${'  ' * depth}- ${p.name}");

    if (showInstances) {
      buff.write(': $node');
    }

    buff.writeln();
    for (var child in node.children.values) {
      doNode(child as LocalNode, depth + 1);
    }
  }

  doNode(root);
  return buff.toString().trim();
}