onInvoke method

  1. @override
Future<List<List<ByteData>>> onInvoke(
  1. Map params
)
override

This is called when this node is invoked. You can return the following types from this method:

You can also return a future that resolves to one (like if the method is async) of the following types:

Implementation

@override
Future<List<List<ByteData>>> onInvoke(Map params) async {
  String name = params['Icon'];
  var resolver = provider._iconResolver;

  var data = await resolver!(name);

  return [
    [data],
  ];
}