CryptoProvider class abstract

Constructors

CryptoProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
random DSRandom
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

assign(PublicKey? publicKeyRemote, ECDH? old) Future<ECDH>
base64_sha256(Uint8List bytes) String
generate() Future<PrivateKey>
generateSync() PrivateKey
getKeyFromBytes(Uint8List bytes) PublicKey
getSecret(PublicKey publicKeyRemote) Future<ECDH>
loadFromString(String str) PrivateKey
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

sha256(List<int> list) String