ECDH class abstract

Implementers

Constructors

ECDH()

Properties

encodedPublicKey String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hashSalt(String salt) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verifySalt(String salt, String hash) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

assign(PublicKey? publicKeyRemote, ECDH? old) Future<ECDH>