responderPath property
String
get
responderPath
user when the requester is proxied to another responder
Implementation
String get responderPath;
user when the requester is proxied to another responder
String get responderPath;