PrivateKey class abstract

Constructors

PrivateKey.generateSync()
factory
PrivateKey.loadFromString(String str)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
publicKey PublicKey
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSecret(String tempKey) Future<ECDH>
get the secret from the remote public key
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveToString() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate() Future<PrivateKey>