PublicKey class abstract

Constructors

PublicKey()
PublicKey.fromBytes(Uint8List bytes)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
qBase64 String
no setter
qHash64 String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDsId(String prefix) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verifyDsId(String dsId) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited