utils library

Common Utilities for DSA Components

Classes

Base64
difference from crypto lib CryptoUtils.bytesToBase64:
BinaryData
BroadcastStreamController<T>
ByteDataUtil
CachedStreamWrapper<T>
Disposable
DsaJson
DsaJsonCodecImpl
DsalinkJSON
DSALogUtils
DsCodec
DsMsgPackCodecImpl
DsTimer
FunctionDisposable
Interval
Scheduler
Schedule Tasks
TimerFunctions
UriComponentDecoder
a decoder class to decode malformed url encoded string

Constants

alphabet → const List<String>
DSA_VERSION → const String
The DSA Version
numbers → const List<int>
specials → const List<String>

Properties

DEBUG_MODE bool
Gets if we are in checked mode.
no setter
logger → Logger
Fetches the logger instance.
no setter

Functions

awaitWithTimeout(Future future, int timeoutMs, {Function? onTimeout, Function? onSuccessAfterTimeout, Function? onErrorAfterTimeout}) Future
BuildActionIO(Map<String, String> types) List<Map>
BuildEnumType(Iterable<String> values) String
countCharacterFrequency(String input, String char) int
foldList(List a, Uint8List b) List
generateBasicId({int length = 30}) String
generateToken({int length = 50}) String
parseEnumType(String type) List<String>
toUTF8(String str) Uint8List
UpdateLogLevel(String name) → void
Updates the log level to the level specified name.

Typedefs

ExecutableFunction = dynamic Function()
Producer<T> = T Function()
Taker<T> = dynamic Function(T value)
TwoTaker<A, B> = dynamic Function(A a, B b)