onCancel property

  1. @override
ControllerCancelCallback? get onCancel
override

The callback which is called when the stream is canceled.

May be set to null, in which case no callback will happen.

Implementation

@override
ControllerCancelCallback? get onCancel => null;
  1. @override
set onCancel (dynamic onCancelHandler()?)
override

The callback which is called when the stream is canceled.

May be set to null, in which case no callback will happen.

Implementation

@override
set onCancel(Function()? onCancelHandler) {
  throw ('BroadcastStreamController.onCancel not implemented');
}