onListen property
The callback which is called when the stream is listened to.
May be set to null, in which case no callback will happen.
Implementation
@override
ControllerCallback? get onListen => null;
The callback which is called when the stream is listened to.
May be set to null, in which case no callback will happen.
Implementation
@override
set onListen(void Function()? onListenHandler) {
throw ('BroadcastStreamController.onListen not implemented');
}