ByteDataUtil class

Constructors

ByteDataUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromList(List<int> input) ByteData
fromUint8List(Uint8List uintsList) ByteData
list2Uint8List(List<int> input) Uint8List
mergeBytes(List<ByteData> bytesList) ByteData
toUint8List(ByteData bytes) Uint8List