DsCodec class abstract

Implementers

Constructors

DsCodec()

Properties

blankData Object?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeBinaryFrame(List<int> input) Map?
decodeStringFrame(String input) Map?
input can be String or List
encodeFrame(Map val) Object?
output String or List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaultCodec DsCodec
final

Static Methods

getCodec(String name) DsCodec
register(String? name, DsCodec? codec) → void