DsMsgPackCodecImpl class

Inheritance

Constructors

DsMsgPackCodecImpl()

Properties

blankData Object?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeBinaryFrame(List<int> input) Map
override
decodeStringFrame(String input) Map
input can be String or List
override
encodeFrame(Map val) Object?
output String or List
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DsMsgPackCodecImpl
getter/setter pair