DsTimer class
Constructors
- DsTimer()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- timerTimer ↔ Timer?
-
getter/setter pair
- timerTs50 ↔ int
-
getter/setter pair
Static Methods
-
callLater(
Function callback) → void -
millisecondsSinceEpoch(
) → int -
runNow(
) → void -
timerCancel(
Function callback) → void -
timerOnceAfter(
Function callback, int ms) → void - do nothing if the callback is already in the list and will get called after N or more ms
-
timerOnceBefore(
Function callback, int ms) → void - do nothing if the callback is already in the list and will get called after 0 ~ N ms
-
timerOnceBetween(
Function callback, int after, int before) → void - do nothing if the callback is already in the list and will get called after M to N ms
-
waitAndRun(
Duration time, dynamic action()) → Future