DsaJson class abstract

Implementers

Constructors

DsaJson()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeJson(String str) → dynamic
encodeJson(Object val, {bool pretty = false}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DsaJsonCodecImpl
getter/setter pair

Static Methods

decode(String str) → dynamic
Decodes a string using the instance's decodeJson method.
encode(Object val, {bool pretty = false}) String