DsaJsonCodecImpl class
Constructors
Properties
- blankData → Object?
-
no setterinherited
- decoder ↔ JsonDecoder
-
getter/setter pair
- encoder ↔ JsonEncoder
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decodeBinaryFrame(
List< int> bytes) → Map? -
override
-
decodeJson(
String str) → dynamic -
Decodes a JSON string into a dynamic object.
override
-
decodeStringFrame(
String str) → Map? -
input can be String or List
override
-
encodeFrame(
Object val) → Object? -
output String or List
override
-
encodeJson(
Object val, {bool pretty = false}) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited