DsalinkJSON class

Constructors

DsalinkJSON()
DsalinkJSON.from(Map? map)
factory

Properties

configs Map<String, Map>
getter/setter pair
description String?
getter/setter pair
engines Map?
getter/setter pair
getDependencies List<String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
json Map?
no setter
main String?
getter/setter pair
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() Map
toString() String
A string representation of this object.
inherited
verify() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited