TimerFunctions class final

Inheritance

Constructors

TimerFunctions(int ts50)

Properties

hashCode int
The hash code for this object.
no setterinherited
list LinkedList<TimerFunctions>?
The linked list containing this element.
no setterinherited
next TimerFunctions?
The successor of this element in its linked list.
no setterinherited
previous TimerFunctions?
The predecessor of this element in its linked list.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ts50 int
for better performance, use a low accuracy timer, ts50 is the floor of ts/50
final

Methods

add(Function foo) → void
insertAfter(TimerFunctions entry) → void
Insert an element after this element in this element's linked list.
inherited
insertBefore(TimerFunctions entry) → void
Insert an element before this element in this element's linked list.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(Function foo) → void
toString() String
A string representation of this object.
inherited
Unlink the element from its linked list.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited