Worker class

Constructors

Worker(SendPort? port, [Map? meta])

Properties

hashCode int
The hash code for this object.
no setterinherited
metadata Map
final
port SendPort?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createSocket() WorkerSocket
get(String key) → dynamic
has(String key) bool
init({Map<String, Taker>? methods}) Future<WorkerSocket>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited