WorkerBuilder class

Constructors

WorkerBuilder()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hosts Map<String, Taker>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slaves Map<String, Taker>
final

Methods

global(String name, Taker function) WorkerBuilder
host(String name, Function function) WorkerBuilder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
slave(String name, Taker function) WorkerBuilder
spawn([WorkerFunction? function]) Future<WorkerSocket>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

defaultWorkerFunction(Worker worker) Future<WorkerSocket>