SecureRandomBase class abstract

Implemented types
  • Algorithm

Constructors

SecureRandomBase()

Properties

algorithmName String
Get this algorithm's standard name.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

nextBigInteger(int bitLength) BigInt
Get a random BigInteger of bitLength bits.
override
nextBytes(int count) Uint8List
Get a list of bytes of arbitrary length.
override
nextUint16() int
Get two bytes long random int.
override
nextUint32() int
Get four bytes long random int.
override
nextUint8() int
Get one byte long random int.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
seed(CipherParameters params) → void
Seed the RNG with some entropy (look at package cipher_entropy providing entropy sources).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited