ClientLink class abstract
Base Class for Client Link implementations.
- Inheritance
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logName → String?
-
no setter
- nonce → ECDH?
-
no setterinherited
-
onRequesterReady
→ Future<
Requester?> -
trigger when requester channel is Ready
no setterinherited
- privateKey → PrivateKey
-
no setter
- requester → Requester?
-
no setterinherited
- responder → Responder?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void -
inherited
-
connect(
) → void -
formatLogMessage(
String msg) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateSalt(
String salt) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited