Node class
Base Class for any and all nodes in the SDK. If you are writing a link, please look at the dsalink.responder.SimpleNode class.
- Implementers
Constructors
- Node()
Properties
-
attributes
↔ Map<
String, Object?> -
Node Attributes
getter/setter pair
-
children
↔ Map<
String, Node> -
Node Children
Map of Child Name to Child Node
getter/setter pair
- configs ↔ Map
-
Node Configs
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- profile ↔ Node?
-
This node's profile.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addChild(
String name, Node node) → void - Adds a child to this node.
-
forEachAttribute(
void callback(String name, Object? value)) → void -
forEachChild(
void callback(String name, Node? node)) → void -
Iterates over all the children of this node and passes them to the specified
callback. -
forEachConfig(
void callback(dynamic name, dynamic value)) → void -
get(
String name) → Object? -
Get a property of this node.
If
namestarts with '$', this will fetch a config. Ifnamestarts with a '@', this will fetch an attribute. Otherwise this will fetch a child. -
getAttribute(
String name) → Object? - Get an Attribute
-
getChild(
String name) → Node? - Get a Child Node
-
getConfig(
String name) → Object? - Get a Config
-
getOverideAttributes(
String attr) → Object? - same as attributes for local node but different on remote node
-
getSimpleMap(
) → Map - Gets a map for the data that will be listed in the parent node's children property.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeChild(
dynamic input) → String? -
Remove a child from this node.
inputcan be either an instance of Node or a String. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getDisplayName(
String nameOrPath) → String