ProcessorResult class
generate message right before sending to get the latest update return messages and the processors that need ack callback
Constructors
-
ProcessorResult(List<
Map> messages, List<ConnectionProcessor> processors)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
↔ List<
Map> -
getter/setter pair
-
processors
↔ List<
ConnectionProcessor> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited