HistorianDatabaseAdapter class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addWatchGroupExtensions(
WatchGroupNode node) → void -
addWatchPathExtensions(
WatchPathNode node) → void -
close(
) → Future -
fetchHistory(
String group, String path, TimeRange range) → Stream< ValuePair> -
getSummary(
String? group, String path) → Future< HistorySummary> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
purgeGroup(
String group, TimeRange range) → Future -
purgePath(
String group, String path, TimeRange range) → Future -
store(
List< ValueEntry> entries) → Future -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited