onInvoke method
This is called when this node is invoked. You can return the following types from this method:
You can also return a future that resolves to one (like if the method is async) of the following types:
Implementation
@override
dynamic onInvoke(Map params) {
if (onActionInvoke != null) {
return onActionInvoke!(params);
} else {
return super.onInvoke(params);
}
}