ResolvingNodeProvider class

Inheritance

Constructors

ResolvingNodeProvider([Map? defaultNodes, Map<String, NodeFactory>? profiles])

Properties

defs SimpleHiddenNode?
defs node
getter/setter pairinherited
handler ResolveNodeHandler?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nodes Map<String, LocalNode>
All the nodes in this node provider.
finalinherited
permissions IPermissionManager
Permissions
getter/setter pairinherited
profileMap Map<String, NodeFactory>
no setterinherited
root SimpleNode
Root node
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sys SimpleHiddenNode?
sys node
getter/setter pairinherited

Methods

addNode(String path, Map m) SimpleNode?
Adds a node at the given path that is initialized with the given data in m.
override
addProfile(String name, NodeFactory factory) → void
inherited
createNode(String path, [bool init = true]) SimpleNode
Creates a node at path. If a node already exists at this path, an exception is thrown. If init is false, onCreated() is not called.
inherited
createResponder(String? dsId, String sessionId) Responder
Creates a responder with the given dsId.
inherited
getNode(String path, {Completer<CallbackNode?>? onLoaded, bool forceHandle = false}) LocalNode?
Gets an existing node.
override
getOrCreateNode(String path, [bool addToTree = true, bool init = true]) LocalNode
Gets a node at the given path if it exists. If it does not exist, create a new node and return it.
override
hasNode(String path) bool
Checks if this provider has the node at path.
inherited
init([Map? m, Map<String, NodeFactory>? profiles]) → void
Initialize the node provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
persist([bool now = false]) → void
Persist the nodes in this provider. If you are not using a LinkProvider, then call setPersistFunction to set the function that is called to persist.
inherited
registerResolver(SimpleNodeFactory factory) → void
inherited
removeNode(String path, {bool recurse = true}) → void
Removes the node specified at path.
inherited
save() Map
Save the node provider to a map.
inherited
setIconResolver(IconResolver resolver) → void
inherited
setNode(String path, SimpleNode node, {bool registerChildren = false}) → void
Sets the given node to the given path.
inherited
setPersistFunction(ExecutableFunction doPersist) → void
Sets the function that persists the nodes.
inherited
toString({bool showInstances = false}) String
A string representation of this object.
inherited
unregisterResolver(SimpleNodeFactory factory) → void
inherited
updateValue(String path, Object? value) → void
Updates the value of the node at path to the given value.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String path) LocalNode?
Gets an existing node, or creates a dummy node for a requester to listen on.
inherited
operator ~() LocalNode
Get the root node.
inherited