getOrCreateNode method
Gets a node at the given path if it exists.
If it does not exist, create a new node and return it.
When addToTree is false, the node will not be inserted into the node provider.
Implementation
@override
LocalNode getOrCreateNode(String path, [bool addToTree = true]) {
return node;
}