BrokerQueryCommand class abstract
- Implementers
Constructors
- BrokerQueryCommand(BrokerQueryManager _manager)
Properties
- base ↔ BrokerQueryCommand?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nexts
↔ Set<
BrokerQueryCommand> -
getter/setter pair
-
responses
↔ Set<
InvokeResponse> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addNext(
BrokerQueryCommand next) → void -
addResponse(
InvokeResponse response) → void -
destroy(
) → void -
getQueryId(
) → String - return a unified String as the key of the map
-
init(
) → void - init after checking command is not a duplication
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeNext(
BrokerQueryCommand next) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateFromBase(
List updats) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited