QueryCommandSubscribe class
- Inheritance
-
- Object
- BrokerQueryCommand
- QueryCommandSubscribe
Constructors
- QueryCommandSubscribe(BrokerQueryManager manager)
Properties
- base ↔ BrokerQueryCommand?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nexts
↔ Set<
BrokerQueryCommand> -
getter/setter pairinherited
-
responses
↔ Set<
InvokeResponse> -
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subscriptions
↔ Map<
String, _QuerySubscription> -
getter/setter pair
Methods
-
addNext(
BrokerQueryCommand next) → void -
inherited
-
addResponse(
InvokeResponse response) → void -
override
-
destroy(
) → void -
override
-
getQueryId(
) → String -
return a unified String as the key of the map
inherited
-
init(
) → void -
init after checking command is not a duplication
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeNext(
BrokerQueryCommand next) → void -
inherited
-
toString(
) → String -
A string representation of this object.
override
-
updateFromBase(
List updates) → void -
override
-
updatePath(
String path) → void -
updateRow(
List? row) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited