RemoteNode class
- Inheritance
- Implementers
Constructors
- RemoteNode(String remotePath)
Properties
-
attributes
↔ Map<
String, Object?> -
Node Attributes
getter/setter pairinherited
-
children
↔ Map<
String, Node> -
Node Children
Map of Child Name to Child Node
getter/setter pairinherited
- configs ↔ Map
-
Node Configs
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasValueUpdate → bool
-
no setter
- lastValueUpdate → ValueUpdate?
-
no setter
- listed ↔ bool
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- profile ↔ Node?
-
This node's profile.
getter/setter pairinherited
- remotePath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscribeController → ReqSubscribeController?
-
no setter
Methods
-
addChild(
String name, Node node) → void -
Adds a child to this node.
inherited
-
createListController(
Requester requester) → ListController - need a factory function for children class to override
-
forEachAttribute(
void callback(String name, Object? value)) → void -
inherited
-
forEachChild(
void callback(String name, Node? node)) → void -
Iterates over all the children of this node and passes them to the specified
callback.inherited -
forEachConfig(
void callback(dynamic name, dynamic value)) → void -
inherited
-
get(
String name) → Object? -
Get a property of this node.
If
namestarts with '$', this will fetch a config. Ifnamestarts with a '@', this will fetch an attribute. Otherwise this will fetch a child.inherited -
getAttribute(
String name) → Object? -
Get an Attribute
inherited
-
getChild(
String name) → Node? -
Get a Child Node
inherited
-
getConfig(
String name) → Object? -
Get a Config
inherited
-
getOverideAttributes(
String attr) → Object? -
same as attributes for local node
but different on remote node
inherited
-
getSimpleMap(
) → Map -
Gets a map for the data that will be listed in the parent node's children property.
inherited
-
isSelfUpdated(
) → bool - whether the node's own data is updated
-
isUpdated(
) → bool - node data is not ready until all profile and mixins are updated
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeChild(
dynamic input) → String? -
Remove a child from this node.
inputcan be either an instance of Node or a String.inherited -
resetNodeCache(
) → void - clear all configs attributes and children
-
save(
{bool includeValue = true}) → Map -
toString(
) → String -
A string representation of this object.
inherited
-
updateRemoteChildData(
Map m, RemoteNodeCache cache) → void - used by list api to update simple data for children
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited