Request class
request class handles raw response from responder Represents a request made by the requester.
This class encapsulates the necessary information for a request, including the requester instance, request ID, request data, and a callback for updating the request status.
- Implementers
Constructors
- Request(Requester requester, int rid, RequestUpdater updater, Map? data)
Properties
- data → Map?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isClosed → bool
-
no setter
- requester → Requester
-
final
- rid → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamStatus ↔ String
-
getter/setter pair
- updater → RequestUpdater
-
The callback function for updating the request status.
final
Methods
-
addReqParams(
Map m) → void - Adds request parameters to the send list.
-
close(
) → void - Closes the request from the client side.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resend(
) → void - Resends the data if the previous sending failed.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited