close method
void
close()
Closes the request from the client side.
This method is used to close the request from the client side. It will also be called later from the requester.
Implementation
void close() {
requester.closeRequest(this);
}