Requester class
- Inheritance
-
- Object
- ConnectionHandler
- Requester
Constructors
- Requester([RemoteNodeCache? cache])
Properties
- connection ↔ ConnectionChannel?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastRid ↔ int
-
getter/setter pair
- nodeCache → RemoteNodeCache
-
caching of nodes
final
-
onError
→ Stream<
DSError> -
no setter
- openRequestCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionCount → int
-
no setter
Methods
-
addProcessor(
ConnectionProcessor processor) → void -
a processor function that's called just before the data is sent
same processor won't be added to the list twice
inside processor, send() data that only need to appear once per data frame
inherited
-
addToSendList(
Map m) → void -
inherited
-
clearProcessors(
) → void -
inherited
-
closeRequest(
Request request) → void - close the request from requester side and notify responder
-
getNextRid(
) → int -
getNodeValue(
String path, {Duration? timeout}) → Future< ValueUpdate> -
getRemoteNode(
String path) → Future< RemoteNode> -
getSendingData(
int currentTime, int waitingAckId) → ProcessorResult -
gather all the changes from
override
-
invoke(
String path, [Map params = const {}, int maxPermission = Permission.CONFIG, RequestConsumer? fetchRawReq]) → Stream< RequesterInvokeUpdate> -
isNodeCached(
String path) → bool -
list(
String path) → Stream< RequesterListUpdate> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onData(
List list) → void -
override
-
onDisconnected(
) → void -
override
-
onReconnected(
) → void -
override
-
onValueChange(
String path, [int qos = 0]) → Stream< ValueUpdate> -
remove(
String path) → Future< RequesterUpdate> -
sendRequest(
Map m, RequestUpdater updater) → Request? -
set(
String path, Object? value, [int maxPermission = Permission.CONFIG]) → Future< RequesterUpdate> -
subscribe(
String path, dynamic callback(ValueUpdate update), [int qos = 0]) → ReqSubscribeListener -
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
String path, dynamic callback(ValueUpdate update)) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited