RequesterInvokeUpdate class
- Inheritance
-
- Object
- RequesterUpdate
- RequesterInvokeUpdate
Constructors
-
RequesterInvokeUpdate(List? updates, List? rawColumns, List<
TableColumn> ? columns, String streamStatus, {Map? meta, DSError? error})
Properties
-
columns
↔ List<
TableColumn> ? -
getter/setter pair
- error ↔ DSError?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta ↔ Map?
-
getter/setter pair
- rawColumns ↔ List?
-
getter/setter pair
-
rows
→ List<
List> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamStatus → String?
-
finalinherited
- updates ↔ List?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited