RequesterListUpdate class
Properties
-
changes
↔ List?
-
this is only a list of changed fields
when changes is null, means everything could have been changed
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
node
↔ RemoteNode
-
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
streamStatus
→ String?
-
finalinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited