SetController class
- Implemented types
Constructors
- SetController(Requester requester, String path, Object? value, [int maxPermission = Permission.CONFIG])
Properties
-
completer
→ Completer<
RequesterUpdate> -
final
-
future
→ Future<
RequesterUpdate> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
final
- requester → Requester
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → Object?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDisconnect(
) → void -
override
-
onReconnect(
) → void -
override
-
onUpdate(
String? status, List? updates, List? columns, Map? meta, DSError? error) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited