SubscribeController class
only a place holder for reconnect and disconnect real logic is in SubscribeRequest itself
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- request ↔ SubscribeRequest?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDisconnect(
) → void -
override
-
onReconnect(
) → void -
override
-
onUpdate(
String? status, List? updates, List? columns, Map? meta, DSError? error) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited