SubscribeRequest class

Inheritance
Implemented types

Constructors

SubscribeRequest(Requester requester, int rid)

Properties

data Map?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isClosed bool
no setterinherited
lastSid int
getter/setter pair
requester Requester
finalinherited
rid int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamStatus String
getter/setter pairinherited
subscriptionIds Map<int, ReqSubscribeController>
final
subscriptions Map<String, ReqSubscribeController>
final
toRemove Map<int, ReqSubscribeController>
getter/setter pair
updater RequestUpdater
The callback function for updating the request status.
finalinherited

Methods

ackReceived(int receiveAckId, int startTime, int currentTime) → void
override
addReqParams(Map m) → void
Adds request parameters to the send list.
inherited
addSubscription(ReqSubscribeController controller, int level) → void
close() → void
Closes the request from the client side.
inherited
getNextSid() int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepareSending() → void
removeSubscription(ReqSubscribeController controller) → void
resend() → void
Resends the data if the previous sending failed.
override
startSendingData(int currentTime, int waitingAckId) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited