AsyncTableResult class
An Asynchronous Table Result This can be used to return asynchronous tables from actions.
Constructors
- AsyncTableResult([List? columns])
Properties
- columns ↔ List?
-
Table Columns
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta ↔ Map?
-
Table Metadata
getter/setter pair
- onClose ↔ OnInvokeClosed?
-
Handler for when this is closed.
getter/setter pair
- response ↔ InvokeResponse?
-
Invoke Response.
getter/setter pair
- rows ↔ List?
-
Table Rows
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String
-
Stream Status
getter/setter pair
Methods
-
close(
) → void - Closes this response.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
List rows, [String? stat, Map? meta]) → void -
Updates table rows to
rows.statis the stream status.metais the action result metadata. -
write(
[InvokeResponse? resp]) → void -
Write this result to the result given by
resp.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited