IStorageManager class abstract
general purpose storage class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
destroySubscriptionStorage(
String responderPath) → void - destroy subscription storage
-
destroyValueStorageBucket(
String name) → void -
getOrCreateSubscriptionStorage(
String responderPath) → ISubscriptionResponderStorage - get subscription storage responder path point to a local responder node which means the dsalink on the other side of the connection is a requester
-
getOrCreateValueStorageBucket(
String name) → IValueStorageBucket - general key/value pair storage
-
loadSubscriptions(
) → Future< List< List< >ISubscriptionNodeStorage> > - load all saved subscriptions should be called only during application initialization
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited