ISubscriptionNodeStorage class abstract
the storage of one value
Constructors
- ISubscriptionNodeStorage(String path, ISubscriptionResponderStorage storage)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
final
- qos ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storage → ISubscriptionResponderStorage
-
final
Methods
-
addValue(
ValueUpdate value) → void - add data to List of values
-
clear(
int qos) → void - clear the values, but still leave the qos data in storage
-
destroy(
) → void -
getLoadedValues(
) → List< ValueUpdate> - return the existing storage values should be called only during application initialization and value will only be available after parent's load() function is finished
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeValue(
ValueUpdate value) → void - for some database it's easier to remove data one by one removeValue and valueRemoved will be both called, either one can be used
-
setValue(
Iterable< ValueUpdate> removes, ValueUpdate newValue) → void -
set value to newValue and clear all existing values in the storage
removesis only designed for database that can't directly remove all data in a key. ValueUpdate.storedData can be used to store any helper data for the storage class -
toString(
) → String -
A string representation of this object.
inherited
-
valueRemoved(
Iterable< ValueUpdate> updates) → void -
for some database it's easier to remove multiple data together
removeValue and valueRemoved will be both called, either one can be used
updatesare all the remaining value that are still in the list
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited