InvokeResponse class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- node → LocalNode?
-
final
- onClose ↔ OnInvokeClosed?
-
getter/setter pair
- onReqParams ↔ OnReqParams?
-
getter/setter pair
- onSendUpdate ↔ OnInvokeSend?
-
getter/setter pair
- parentNode → LocalNode
-
final
-
pendingData
↔ List<
_InvokeResponseUpdate> -
getter/setter pair
- responder → Responder
-
finalinherited
- rid → int
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sentStreamStatus → String
-
no setterinherited
- type ↔ String?
-
getter/setter pairinherited
Methods
-
ackReceived(
int receiveAckId, int startTime, int currentTime) → void -
inherited
-
close(
[DSError? err]) → void -
close the request from responder side and also notify the requester
override
-
getTraceData(
[String change = '+']) → ResponseTrace -
for the broker trace action
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prepareSending(
) → void -
inherited
-
startSendingData(
int currentTime, int waitingAckId) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateReqParams(
Map m) → void - new parameter from the requester
-
updateStream(
List updates, {List? columns, String streamStatus = StreamStatus.open, Map? meta, bool autoSendColumns = true}) → void - update data for the responder stream
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited