NodeProviderImpl class abstract
- Inheritance
-
- Object
- NodeProvider
- NodeProviderImpl
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nodes
→ Map<
String, dynamic> -
no setter
- permissions → IPermissionManager
-
Get Permissions.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createResponder(
String? dsId, String sessionId) → Responder -
Create a Responder
inherited
-
getNode(
String path) → LocalNode? -
Gets an existing node.
inherited
-
getOrCreateNode(
String path, [bool addToTree = true]) → LocalNode -
Gets a node at the given
pathif it exists. If it does not exist, create a new node and return it.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String path) → LocalNode? -
Gets an existing node, or creates a dummy node for a requester to listen on.
inherited
-
operator ~(
) → LocalNode -
Get the root node.
inherited