Response class
- Implemented types
- Implementers
Properties
Methods
-
ackReceived(
int receiveAckId, int startTime, int currentTime) → void -
override
-
close(
[DSError? err]) → void - close the request from responder side and also notify the requester
-
getTraceData(
[String change = '+']) → ResponseTrace? - for the broker trace action
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prepareSending(
) → void -
startSendingData(
int currentTime, int waitingAckId) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited