displayName property
String?
get
displayName
Gets the current display name of this node. This is the $name config. If it does not exist, then null is returned.
Implementation
String? get displayName => configs[r'$name'] as String?;
set
displayName
(String? value)
Sets the display name of this node. This is the $name config. If this is set to null, then the display name is removed.
Implementation
set displayName(String? value) {
if (value == null) {
configs.remove(r'$name');
} else {
configs[r'$name'] = value;
}
updateList(r'$name');
}