onSetValue method
Callback used to accept or reject a value when it is set. Return true to reject the value, and false to accept it.
Implementation
bool onSetValue(dynamic val) => false;
Callback used to accept or reject a value when it is set. Return true to reject the value, and false to accept it.
bool onSetValue(dynamic val) => false;