writable property
String?
get
writable
Gets the current value of the $writable config. If it does not exist, then null is returned.
Implementation
String? get writable => configs[r'$writable'] as String?;
set
writable
(dynamic value)
Sets the value of the writable config. If this is set to null, then the writable config is removed.
Implementation
set writable(dynamic value) {
if (value == null) {
configs.remove(r'$writable');
} else if (value is bool) {
if (value) {
configs[r'$writable'] = 'write';
} else {
configs.remove(r'$writable');
}
} else {
configs[r'$writable'] = value.toString();
}
updateList(r'$writable');
}