SimpleTableResult class
A simple table result. This is used to return simple tables from an action.
Constructors
- SimpleTableResult([List? rows, List? columns])
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited