SubscribeResponse class
Constructors
- SubscribeResponse(Responder responder, int rid)
Properties
-
changed
→ LinkedHashSet<
RespSubscribeController> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- responder → Responder
-
finalinherited
- rid → int
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sentStreamStatus → String
-
no setterinherited
-
subscriptions
→ Map<
String, RespSubscribeController> -
final
-
subsriptionids
→ Map<
int, RespSubscribeController> -
final
- type ↔ String?
-
getter/setter pairinherited
Methods
-
ackReceived(
int receiveAckId, int startTime, int currentTime) → void -
override
-
add(
String path, LocalNode node, int sid, int qos) → RespSubscribeController -
addTraceCallback(
ResponseTraceCallback _traceCallback) → void -
close(
[DSError? err]) → void -
close the request from responder side and also notify the requester
inherited
-
getTraceData(
[String change = '+']) → ResponseTrace? -
for the broker trace action
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prepareSending(
) → void -
override
-
remove(
int sid) → void -
startSendingData(
int currentTime, int waitingAckId) → void -
override
-
subscriptionChanged(
RespSubscribeController controller) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited