Base64 class
difference from crypto lib CryptoUtils.bytesToBase64:
- default to url filename safe base64
- allow byte array to have negative int -128 ~ -1
- custom line size and custom padding space
Constructors
- Base64()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited