BinaryData class
Properties
-
bytes
↔ ByteData?
-
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
mergingList
↔ List<ByteData>?
-
used when only partial data is received
don"t merge them before it's finished
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited