onCancel property
The callback which is called when the stream is canceled.
May be set to null, in which case no callback will happen.
Implementation
@override
ControllerCancelCallback? get onCancel => null;
The callback which is called when the stream is canceled.
May be set to null, in which case no callback will happen.
Implementation
@override
set onCancel(Function()? onCancelHandler) {
throw ('BroadcastStreamController.onCancel not implemented');
}