Scheduler class
Schedule Tasks
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- currentTimer → Timer
-
no setter
Static Methods
-
after(
Duration duration, dynamic action()) → Future< void> -
cancelCurrentTimer(
) → void -
every(
dynamic interval, dynamic action()) → Timer -
later(
dynamic action()) → Future -
repeat(
int times, dynamic action()) → Future -
runAfter(
Duration duration, dynamic action()) → Timer -
runLater(
dynamic action()) → void -
safeEvery(
dynamic interval, dynamic action()) → Disposable -
tick(
int times, Interval interval, dynamic action()) → Future